{% load static %}
<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8" />
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <meta name="description" content="Sample description "> <!-- # Customize content for search -->
        {% block title %}<title>bookmark and tag sample</title> {% endblock title %}<!-- Enable title changes -->
        <link rel="shortcut icon" type="image/png" href="{% static 'img/favicons/favicon.ico' %}"/>
        <link rel="apple-touch-icon" sizes="180x180" href="{% static 'img/favicons/apple-touch-icon.png' %}">
        <link rel="icon" type="image/png" sizes="32x32" href="{% static 'img/favicons/favicon-32x32.png' %}">
        <link rel="icon" type="image/png" sizes="16x16" href="{% static 'img/favicons/favicon-16x16.png' %}">
        {% block custom_css %}
            <link rel="stylesheet" type="text/css" href="{% static 'css/modal.css' %}">
            <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.7.2/font/bootstrap-icons.css">
            <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-1BmE4kWBq78iYhFldvKuhfTAU6auU8tT94WrHftjDbrCEXSU1oBoqyl2QvZ6jIW3" crossorigin="anonymous">
        {% endblock custom_css %}
    </head>
    <body>
        {% include './_nav.html' %}
        {% include './_messages.html' %}
        {% block content %}
        {% endblock content %}
        {% block base_js %}
            <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js" integrity="sha384-ka7Sk0Gln4gmtz2MlQnikT1wXgYsOg+OMhuP+IlRH9sENBO0LRn5q+8nbTov4+1p" crossorigin="anonymous"></script>
            <script src="https://unpkg.com/htmx.org@1.6.1"></script>
            <script src="https://unpkg.com/hyperscript.org@0.9.3"></script>
            <script>document.body.addEventListener("htmx:configRequest", (e) => {e.detail.headers["X-CSRFToken"] = "{{ csrf_token }}";});</script>
        {% endblock base_js %}
    </body>
</html>
