<div id="custom-modal" _="on closeModal add .closing then wait for animationend then remove me">
    <div class="custom-modal-underlay" _="on click trigger closeModal"></div>
    <div class="custom-modal-content">{% include content_template %}</div>
</div>
