# Generated by Django 4.0.1 on 2022-02-04 08:07

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('examples', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='samplequote',
            name='book',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='quotes', to='examples.samplebook'),
        ),
    ]
