<!-- components below revises the targeted <section> as the 'closest section' -->
<section class="my-3">
    <div class="card">
        <div class="card-body">
            {% include './_toggle.html' %} <!-- targets entire section -->
            {% if object_content_for_panel %}
                {{object_content_for_panel}} <!-- must be set as a model property to be used in set_bookmarked_context() -->
            {% else %}
                <h2 class="card-title placeholder-glow">
                <span class="placeholder col-6"></span>
              </h2>
            {% endif %}
            <center class="mb-3">
                {% for tag in user_tags %}
                    {% include './_badge.html' %} <!-- allows delete of each tag -->
                {% endfor %}
            </center>
            {% include './_tag_form.html' %} <!-- targets entire section -->
        </div>
    </div>
</section>
