<h2>{{header}}</h2>
<ul>
    {% for obj in obj_list %}
        <li>
            <a href="{{obj.get_absolute_url}}">
                {{obj}}
            </a>
            {% if user.is_authenticated %}
                {{obj.modal}}
            {% endif %}
        </li>
    {% empty %}
        <h3> No {{header|lower}} supplied. </h3>
    {% endfor %}
</ul>
